import setuptools
import re

with open("requirements.txt", "r") as f:
    requirements = f.readlines()

with open("yni/__init__.py", "r") as f:
    read = f.read()
    version = re.search(r"__version__ = \"(.*?)\"", read).group(1)


def build(setup_kwargs: dict):
    """
    This function is mandatory in order to build the extensions.
    """
    setup_kwargs.update(
        {
            "install_requires": requirements,
            "version": version,
            "packages": setuptools.find_packages(exclude=["tests"], include=["yni"]),
        }
    )



import re
from typing import Dict, Any

from .header import Header


HEADER_REGEX = re.compile("^#(.*)")
KEY_VALUE_REGEX = re.compile("(.*?):(.*)")


class Yni:
    def __init__(self) -> None:
        self.variables: Dict[str, Header] = {}

    @classmethod
    def from_string(cls, string: str):
        ret = {}
        current_header = ret

        for line in string.splitlines():
            if line == "":
                continue
            if line.startswith("#"):
                match = HEADER_REGEX.search(line)
                name = match.group(1)
                current_header = ret[name] = {}
            elif line in ["[", "]"]:
                pass
            else:
                match = KEY_VALUE_REGEX.search(line)
                key, value = match.group(1), match.group(2)
                current_header[key] = value

        yni = cls()
        for header, attributes in ret.items():
            yni.variables[header] = Header(header, attributes)
        return yni

    @classmethod
    def from_file(cls, filename: str):
        with open(filename, "r") as f:
            return cls.from_string(f.read())

    def __repr__(self):
        return repr(self.variables)

    def __getitem__(self, name: str):
        return self.variables[name]

    def __setitem__(self, name: str, value: Any):
        self.variables[name] = value



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['yni']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'yni',
    'version': '0.0.3',
    'description': 'A parser for the yni config file.',
    'long_description': '# yni\n\nA parser for the yni config file.\n\n## Example\n\ntest.py\n\n```py\nfrom yni import Yni\n\nparser = Yni.from_file(\'example.yni\') # here we parse from a file\n\nparser[\'foo\'][\'bar\'] # get the value of the key "bar" from the header "foo", returns "spam"\n# or\nparser.foo.bar # returns "spam"\n```\n\n## Example 2\n\ntest_2.py\n\n```py\nfrom yni import Yni\n\n string = """#foo\n [\n     bar: spam\n ]"""\n\nparser = Yni.from_string(string) # here we parse from a string\n\nparser[\'foo\'][\'bar\'] # get the value of the key "bar" from the header "foo", returns "spam"\n# or\nparser.foo.bar # returns "spam"\n```\n\n## yni file structure\n\nexample.yni\n\n```yni\n#foo\n[\n    bar: spam\n]\n```\n',
    'author': 'Alex Hutz',
    'author_email': 'frostiiweeb@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/FrostiiWeeb/yni',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.8,<4.0',
}
from build import *
build(setup_kwargs)

setup(**setup_kwargs)
